==> risk-center-api-0.4.19-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/RiskSlotDetailDiDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
* 风控广告位规则指标统计表
*/
public class RiskSlotDetailDiDto implements Serializable {

    private static final long serialVersionUID = 6948008530534651894L;

    /**
    * 主键
    */
    private Long id;

    /**
    * 日期
    */
    private Date curDate;

    /**
    * 广告位ID
    */
    private Long slotId;

    /**
    * 广告位落地页曝光pv
    */
    private Long exposePv;

    /**
    * 广告位落地页转化pv
    */
    private Long effectPv;

    /**
    * 广告位券点击pv
    */
    private Long advertClickPv;

    /**
    * 广告位券曝光pv
    */
    private Long advertExposePv;

    /**
    * 广告位落地页访问pv
    */
    private Long visitPv;

    /**
    * 广告位js广告计费点击pv
    */
    private Long chargeClickPv;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 更新时间
    */
    private Date gmtModified;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setExposePv(Long exposePv) {
        this.exposePv = exposePv;
    }

    public Long getExposePv() {
        return exposePv;
    }

    public void setEffectPv(Long effectPv) {
        this.effectPv = effectPv;
    }

    public Long getEffectPv() {
        return effectPv;
    }

    public void setAdvertClickPv(Long advertClickPv) {
        this.advertClickPv = advertClickPv;
    }

    public Long getAdvertClickPv() {
        return advertClickPv;
    }

    public void setAdvertExposePv(Long advertExposePv) {
        this.advertExposePv = advertExposePv;
    }

    public Long getAdvertExposePv() {
        return advertExposePv;
    }

    public void setVisitPv(Long visitPv) {
        this.visitPv = visitPv;
    }

    public Long getVisitPv() {
        return visitPv;
    }

    public void setChargeClickPv(Long chargeClickPv) {
        this.chargeClickPv = chargeClickPv;
    }

    public Long getChargeClickPv() {
        return chargeClickPv;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

}

==> risk-center-api-0.5.58-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/RiskSlotDetailDiDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
* 风控广告位规则指标统计表
*/
public class RiskSlotDetailDiDto implements Serializable {

    private static final long serialVersionUID = 6948008530534651894L;

    /**
    * 主键
    */
    private Long id;

    /**
    * 日期
    */
    private Date curDate;

    /**
    * 广告位ID
    */
    private Long slotId;

    /**
    * 广告位落地页曝光pv
    */
    private Long exposePv;

    /**
    * 广告位落地页转化pv
    */
    private Long effectPv;

    /**
    * 广告位券点击pv
    */
    private Long advertClickPv;

    /**
    * 广告位券曝光pv
    */
    private Long advertExposePv;

    /**
    * 广告位落地页访问pv
    */
    private Long visitPv;

    /**
    * 广告位js广告计费点击pv
    */
    private Long chargeClickPv;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 更新时间
    */
    private Date gmtModified;

    /**
     * 广告位0:00-当前时间点发券pv
     */
    private Long launchPv;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setExposePv(Long exposePv) {
        this.exposePv = exposePv;
    }

    public Long getExposePv() {
        return exposePv;
    }

    public void setEffectPv(Long effectPv) {
        this.effectPv = effectPv;
    }

    public Long getEffectPv() {
        return effectPv;
    }

    public void setAdvertClickPv(Long advertClickPv) {
        this.advertClickPv = advertClickPv;
    }

    public Long getAdvertClickPv() {
        return advertClickPv;
    }

    public void setAdvertExposePv(Long advertExposePv) {
        this.advertExposePv = advertExposePv;
    }

    public Long getAdvertExposePv() {
        return advertExposePv;
    }

    public void setVisitPv(Long visitPv) {
        this.visitPv = visitPv;
    }

    public Long getVisitPv() {
        return visitPv;
    }

    public void setChargeClickPv(Long chargeClickPv) {
        this.chargeClickPv = chargeClickPv;
    }

    public Long getChargeClickPv() {
        return chargeClickPv;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public Long getLaunchPv() {
        return launchPv;
    }

    public void setLaunchPv(Long launchPv) {
        this.launchPv = launchPv;
    }
}
